package com.ruoyi.bst.softwareVersion.service;

import java.util.List;
import com.ruoyi.bst.softwareVersion.domain.SoftwareVersion;
import com.ruoyi.bst.softwareVersion.domain.SoftwareVersionVO;
import com.ruoyi.bst.softwareVersion.domain.SoftwareVersionQuery;

/**
 * 软件版本Service接口
 *
 * @author ruoyi
 * @date 2025-04-07
 */
public interface SoftwareVersionService
{
    /**
     * 查询软件版本
     *
     * @param id 软件版本主键
     * @return 软件版本
     */
    public SoftwareVersionVO selectSoftwareVersionById(Long id);

    /**
     * 查询软件版本列表
     *
     * @param softwareVersion 软件版本
     * @return 软件版本集合
     */
    public List<SoftwareVersionVO> selectSoftwareVersionList(SoftwareVersionQuery softwareVersion);

    /**
     * 新增软件版本
     *
     * @param softwareVersion 软件版本
     * @return 结果
     */
    public int insertSoftwareVersion(SoftwareVersion softwareVersion);

    /**
     * 修改软件版本
     *
     * @param softwareVersion 软件版本
     * @return 结果
     */
    public int updateSoftwareVersion(SoftwareVersion softwareVersion);

    /**
     * 批量删除软件版本
     *
     * @param ids 需要删除的软件版本主键集合
     * @return 结果
     */
    public int deleteSoftwareVersionByIds(Long[] ids);

    /**
     * 删除软件版本信息
     *
     * @param id 软件版本主键
     * @return 结果
     */
    public int deleteSoftwareVersionById(Long id);
}
